@@ -2,7 +2,7 @@ package App::proxyforurl;
 use strict;
 use warnings;
 
-our $VERSION = '0.12';
+our $VERSION = '1.00';
 
 1;
 
@@ -22,23 +22,47 @@ L<App::proxyforurl> is a web application that can be used to test proxy PAC
 files.
 
 The L<server side|Mojolicious> is used to serve the web page, but does also
-provide functionlity for resolving hostnames and checking if an IP is within
+provide functionality for resolving hostnames and checking if an IP is within
 a given net.
 
 =head2 Demo
 
-Check out L<https://app.thorsen.pm/proxyforurl> for a running example.
+Check out L<https://thorsen.pm/proxyforurl> for a running example.
 
 =head2 Missing features
 
 The client side PAC parser does not fully support C<dateRange()>, C<timeRange()>
 or C<weekdayRange()>. These functions simply return true, no matter what the
-intput is.
+input is.
 
 =head1 SYNOPSIS
 
   $ proxyforurl --listen http://*:8080;
 
+With optional environment variables:
+
+  $ PROXYFORURL_TEMPLATES=/path/to/templates \
+    PROXYFORURL_BRAND_NAME=Thorsen \
+    PROXYFORURL_BRAND_URL=https://thorsen.pm \
+    PROXYFORURL_X_REQUEST_BASE="https://thorsen.pm/proxyforurl" \
+    proxyforurl --listen http://*:8080;
+
+=over 2
+
+=item * PROXYFORURL_TEMPLATES
+
+Can be set to a custom directory to override templates.
+
+=item * PROXYFORURL_BRAND_NAME, PROXYFORURL_BRAND_URL
+
+Used to change the menu item text and URL.
+
+=item * PROXYFORURL_X_REQUEST_BASE
+
+Can be set to a custom request base, in case the app is not mounted at "/".
+
+=back
+
 =head1 SEE ALSO
 
 =over 4
